@@ -4,13 +4,15 @@
 
 library(usl)
 
-data(specsdm91)
+data(raytracer)
 
-options(digits=3)
+options(digits=3, scipen=6)
 
 set.seed(1103, kind = "default", normal.kind = "default")
 
-u <- usl(throughput ~ load, data = specsdm91, R = 50)
+u <- usl(throughput ~ processors, data = raytracer)
+
+coef(u)
 
 confint(u, parm=1)
 confint(u, parm="sigma")
